==> haskell-abstract-deque-0.3-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-deque
version: 0.3
id: abstract-deque-0.3-Je8wHqkpAgX62s0JMbUyxw
key: abstract-deque-0.3-Je8wHqkpAgX62s0JMbUyxw
license: BSD-3-Clause
maintainer: rrnewton@gmail.com
author: Ryan R. Newton
homepage: https://github.com/rrnewton/haskell-lockfree/wiki
synopsis: Abstract, parameterized interface to mutable Deques.
description:
    An abstract interface to highly-parameterizable queues/deques.
    .
    Background: There exists a feature space for queues that extends between:
    .
    * simple, single-ended, non-concurrent, bounded queues
    .
    * double-ended, threadsafe, growable queues
    .
    ... with important points inbetween (such as
    the queues used for work-stealing).
    .
    This package includes an interface for Deques that allows the
    programmer to use a single API for all of the above, while using the
    type-system to select an efficient implementation given the
    requirements (using type families).
    .
    This package also includes a simple reference implementation based
    on '\''IORef'\'' and "Data.Sequence".
category: Data
abi: 8a585ba1eb46f650f889f89099a67865
exposed: True
exposed-modules:
    Data.Concurrent.Deque.Class Data.Concurrent.Deque.Debugger
    Data.Concurrent.Deque.Reference
    Data.Concurrent.Deque.Reference.DequeInstance
import-dirs: /usr/lib/ghc-8.6.1/site-local/abstract-deque-0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/abstract-deque-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/abstract-deque-0.3
hs-libraries: HSabstract-deque-0.3-Je8wHqkpAgX62s0JMbUyxw
depends:
    array-0.5.2.0 base-4.12.0.0 containers-0.6.0.1
    random-1.1-3ypV4EIycgb35PKjTYYr5q time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-abstract-deque/html/abstract-deque.haddock
haddock-html: /usr/share/doc/haskell-abstract-deque/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-abstract-deque-0.3-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-deque
version: 0.3
id: abstract-deque-0.3-Ea960a5KENXK2d35e54eQH
key: abstract-deque-0.3-Ea960a5KENXK2d35e54eQH
license: BSD-3-Clause
maintainer: rrnewton@gmail.com
author: Ryan R. Newton
homepage: https://github.com/rrnewton/haskell-lockfree/wiki
synopsis: Abstract, parameterized interface to mutable Deques.
description:
    An abstract interface to highly-parameterizable queues/deques.
    .
    Background: There exists a feature space for queues that extends between:
    .
    * simple, single-ended, non-concurrent, bounded queues
    .
    * double-ended, threadsafe, growable queues
    .
    ... with important points inbetween (such as
    the queues used for work-stealing).
    .
    This package includes an interface for Deques that allows the
    programmer to use a single API for all of the above, while using the
    type-system to select an efficient implementation given the
    requirements (using type families).
    .
    This package also includes a simple reference implementation based
    on '\''IORef'\'' and "Data.Sequence".
category: Data
abi: 9084056516d503940340fd43d0ea40fa
exposed: True
exposed-modules:
    Data.Concurrent.Deque.Class Data.Concurrent.Deque.Debugger
    Data.Concurrent.Deque.Reference
    Data.Concurrent.Deque.Reference.DequeInstance
import-dirs: /usr/lib/ghc-8.6.3/site-local/abstract-deque-0.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/abstract-deque-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/abstract-deque-0.3
hs-libraries: HSabstract-deque-0.3-Ea960a5KENXK2d35e54eQH
depends:
    array-0.5.3.0 base-4.12.0.0 containers-0.6.0.1
    random-1.1-3ypV4EIycgb35PKjTYYr5q time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-abstract-deque/html/abstract-deque.haddock
haddock-html: /usr/share/doc/haskell-abstract-deque/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
